@@ -6,13 +6,15 @@
 # copy: (C) Copyright 2013 Cadit Inc., All Rights Reserved.
 #------------------------------------------------------------------------------
 
-import sys, unittest, re
+import sys, unittest, re, time
 import templatealchemy as ta
 
 from .manager import Manager
 from .sender import Sender, StoredSender
 from . import util
 
+#------------------------------------------------------------------------------
+
 def eqstrip(val):
   val = val.replace('\r\n', '\n').replace('\r', '\n')
   val = re.sub('[ \t]+', ' ', val)
@@ -24,11 +26,48 @@ def wsstrip(val):
 def template(s, renderer='mako'):
   return ta.Template(source='string:' + s, renderer=renderer)
 
+#------------------------------------------------------------------------------
+
+def stoptime(at=None):
+  if at is None:
+    at = time.time()
+  at = float(at)
+  if not hasattr(time, '__original_time__'):
+    time.__original_time__ = time.time
+  time.time = lambda: at
+  return at
+
+def unstoptime():
+  if hasattr(time, '__original_time__'):
+    time.time = time.__original_time__
+
+#------------------------------------------------------------------------------
+
+# todo: i should create a class-level decorator version of this too...
+# todo: it should really inspect the extra_requires clause and derive
+#       the 'pkg' value from that...
+def feature(name, module, pkg=None):
+  if pkg is None:
+    pkg = module
+  try:
+    __import__(module)
+    return lambda func: func
+  except ImportError:
+    return unittest.skip('"{}" feature requires package "{}"'.format(name, pkg))
+
 #------------------------------------------------------------------------------
 class TestEmail(unittest.TestCase):
 
   maxDiff = None
 
+  #----------------------------------------------------------------------------
+  def setUp(self):
+    stoptime(1234567890.0) # == 2009-02-13T23:31:30Z 
+
+  #----------------------------------------------------------------------------
+  def tearDown(self):
+    unstoptime()
+
   #----------------------------------------------------------------------------
   def assertXmlEqual(self, val, chk):
     if val == chk:
@@ -283,7 +322,6 @@ Subject: This Is A Test\n\n''' + tchk
 '''
     eml = Manager(sender=StoredSender(), provider=template(tpl)).newEmail()
     # override the UN-predictable generated info...
-    eml.setHeader('Date', 'Fri, 13 Feb 2009 23:31:30 -0000')
     eml.setHeader('Message-ID', '<1234567890@genemail.example.com>')
     eml.includeComponents = ['text']
     eml['message'] = 'This is a test'
@@ -378,7 +416,6 @@ Subject: This Is A Test\n\n''' + tchk
 '''
     eml = Manager(sender=StoredSender(), provider=template(tpl)).newEmail()
     # override the UN-predictable generated info...
-    eml.setHeader('Date', 'Fri, 13 Feb 2009 23:31:30 -0000')
     eml.setHeader('Message-ID', '<1234567890@genemail.example.com>')
     eml.includeComponents = ['text']
     eml['message'] = 'This is a test'
@@ -489,7 +526,6 @@ Content-ID: <smiley.png>
 
     eml = Manager(sender=StoredSender(), provider=template(tpl)).newEmail()
     # override the UNpredictable generated info...
-    eml.setHeader('Date', 'Fri, 13 Feb 2009 23:31:30 -0000')
     eml.setHeader('Message-ID', '<1234567890@genemail.example.com>')
     eml.boundary = 'genemail.test'
     eml['message'] = 'This and that'
@@ -506,7 +542,6 @@ Content-ID: <smiley.png>
     eml1.setHeader('To', 'test@example.com')
     eml1.setHeader('From', 'noreply@example.com')
     eml1.setHeader('Bcc', 'bcc@example.com')
-    eml1.setHeader('Date', 'Fri, 13 Feb 2009 23:31:30 -0000')
     eml1.setHeader('Message-ID', '<1234567890@genemail.example.com>')
     eml1.includeComponents = ['text']
     eml1.send()
@@ -517,7 +552,6 @@ Content-ID: <smiley.png>
     eml2 = man.newEmail()
     eml2.setHeader('To', 'test@example.com')
     eml2.setHeader('From', 'noreply@example.com')
-    eml2.setHeader('Date', 'Fri, 23 Feb 2009 23:32:30 -0000')
     eml2.setHeader('Message-ID', '<2234567890@genemail.example.com>')
     eml2.includeComponents = ['text']
     eml2.send()
